window.Gleam.initSearch([{"doc":"glailglind","title":"glailglind","content":"# Glailglind - Tailwind for Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/glailglind)](https://hex.pm/packages/glailglind)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glailglind/)\n\nInstalls and invokes TailwindCSS CLI.\n\nHeavily inspired by [phoenixframework/tailwind](https://github.com/phoenixframework/tailwind/).\n\nCompatible with Erlang and Javascript targets. (Javascript target requires `curl` to be available on the host)\n\n## Usage as module\n\n### Install Package\n\n```sh\ngleam add glailglind --dev\n```\n\n### Configure TailwindCSS\n\nYou can configure TailwindCSS in your `gleam.toml` by adding a `tailwind` table:\n\n```toml\n[tailwind]\nversion = &quot;3.4.1&quot; # optional\nargs = [\n    &quot;--config=tailwind.config.js&quot;,\n    &quot;--input=./src/css/app.css&quot;,\n    &quot;--output=./priv/css/app.css&quot;\n]\npath = &quot;/path/to/tailwindcli&quot; # optional\n```\n\nThis lets you define the arguments being run.\n\nOptionally define a specific TailwindCSS version or the direct path to the TailwindCSS CLI, if you don&#39;t want it to be installed automatically.\n\n### Install TailwindCSS\n\n```sh\ngleam run -m tailwind/install\n```\n\nThis downloads the Tailwind CLI to `./build/bin/tailwind-cli` and generates the `tailwind.config.js` in the root of the project.\n\n### Import Tailwind in your CSS\n\n```css\n@tailwind base;\n@tailwind components;\n@tailwind utilities;\n```\n\n### Run TailwindCSS\n\n```sh\ngleam run -m tailwind/run\n```\n\nExecutes tailwind with the defined arguments.\n\n## Usage with [LustreSSG](https://github.com/lustre-labs/lustre_ssg)\n\n#### [ℹ️ Lustre Dev Tools have their own TailwindCSS support!](https://github.com/lustre-labs/dev-tools)\n\n### Install Package\n\n```sh\ngleam add glailglind\n```\n\n### (Optional) Specify version in config\n\n`gleam.toml`\n\n```toml\n[tailwind]\nversion = &quot;3.3.5&quot;\n```\n\n### Install TailwindCSS\n\n```sh\ngleam run -m tailwind/install\n```\n\n### Import Tailwind in your CSS\n\n```css\n@tailwind base;\n@tailwind components;\n@tailwind utilities;\n```\n\n### Update build script\n\nImport `tailwind` and add the run step to your build script.\n\nExample:\n\n```gleam\nimport gleam/list\nimport gleam/map\nimport gleam/io\nimport gleam/result\n\n// Some data for your site\nimport app/data/posts\n\n// Some functions for rendering pages\nimport app/page/index\nimport app/page/blog\nimport app/page/post\n\n// Import the static site generator\nimport lustre/ssg\n\n// Import Tailwind\nimport tailwind\n\npub fn main() {\n  let posts = map.from_list({\n    use post &lt;- list.map(posts.all())\n    #(post.id, post)\n  })\n\n  let build =\n    ssg.new(&quot;./priv&quot;)\n    |&gt; ssg.add_static_route(&quot;/&quot;, index.view())\n    |&gt; ssg.add_static_route(&quot;/blog&quot;, blog.view(posts.all()))\n    |&gt; ssg.add_dynamic_route(&quot;/blog&quot;, posts, post.view)\n    |&gt; ssg.build\n    |&gt; result.map_error(fn(e) { string.inspect(e) })\n    |&gt; result.try(fn(_) {\n      [\n        &quot;--config=tailwind.config.js&quot;, &quot;--input=./assets/css/app.css&quot;,\n        &quot;--output=./priv/css/app.css&quot;,\n      ]\n      |&gt; tailwind.run()\n    })\n\n  case build {\n    Ok(m) -&gt; {\n      io.println(m)\n      io.println(&quot;Build succeeded!&quot;)\n    }\n    Error(e) -&gt; {\n      io.debug(e)\n      io.println(&quot;Build failed!&quot;)\n    }\n  }\n}\n```\n","url":"index.html"},{"doc":"tailwind","title":"get_args","content":"pub fn get_args() -&gt; Result(List(String), String)\n Fetches the argument list from the `gleam.toml`.\n \n Public because it&#39;s needed in `tailwind/run`.\nSynonyms:\ntailwind.get_args\ntailwind get_args","url":"tailwind.html#get_args"},{"doc":"tailwind","title":"install","content":"pub fn install() -&gt; Result(Nil, String)\n Downloads the TailwindCSS CLI matching your operating system and architecture.\nSynonyms:\ntailwind.install\ntailwind install","url":"tailwind.html#install"},{"doc":"tailwind","title":"install_and_run","content":"pub fn install_and_run(\n  args: List(String),\n) -&gt; Result(String, String)\n Installs and then executes the TailwindCSS CLI with the passed arguments.\n \n Check `install()` and `run()`.\nSynonyms:\ntailwind.install_and_run\ntailwind install_and_run","url":"tailwind.html#install_and_run"},{"doc":"tailwind","title":"run","content":"pub fn run(args: List(String)) -&gt; Result(String, String)\n Executes the TailwindCSS CLI with the passed arguments.\n # Example\n \n &gt; run([&quot;--config=tailwind.config.js&quot;, &quot;--input=./test/input.css&quot;, &quot;--output=./build/css/output.css&quot;])\n Rebuilding...\n Done in 90ms.\n \nSynonyms:\ntailwind.run\ntailwind run","url":"tailwind.html#run"},{"doc":"tailwind","title":"tailwind","content":" Contains all the functions necessary to install and execute the TailwindCSS CLI.\n ","url":"tailwind.html"},{"doc":"tailwind/run","title":"main","content":"pub fn main() -&gt; Nil\n ⚠️ This function is to be ran directly as gleam module.\n \n  # Example\n     $ gleam run -m tailwind/run\n \n If you wish to run tailwind programmatically use `tailwind.run(args)`.\nSynonyms:\ntailwind/run.main\ntailwind/run main","url":"tailwind/run.html#main"},{"doc":"tailwind/run","title":"tailwind/run","content":" Runs the TailwindCSS CLI with the args defined in the `gleam.toml`.\n \n ⚠️ This module is to be ran directly as gleam module.\n \n  ## Example\n     $ gleam run -m tailwind/run\n ","url":"tailwind/run.html"},{"doc":"tailwind/install","title":"main","content":"pub fn main() -&gt; Result(Nil, String)\n ⚠️ This function is to be ran directly as gleam module.\n \n  # Example\n     $ gleam run -m tailwind/install\n \n If you wish to install tailwind programmatically use `tailwind.install()`.\nSynonyms:\ntailwind/install.main\ntailwind/install main","url":"tailwind/install.html#main"},{"doc":"tailwind/install","title":"tailwind/install","content":" Runs the TailwindCSS install.\n \n ⚠️ This module is to be ran directly as gleam module.\n \n  ## Example\n     $ gleam run -m tailwind/install\n ","url":"tailwind/install.html"}]);